# -*- coding: iso-8859-1 -*-
# -----------------------------------------------------------------------
# Common VDR functions and interfaces
# -----------------------------------------------------------------------
#
# Notes: 
# Used by the vdr TV mode, TVGuide and dvb_radio plugins.
#
# Authors:
#   Thomas Weber, tweber@users.sf.net
#
#
# TODO
# 1) ...
#
# Usage: 
#
# Todo: 
#
# -----------------------------------------------------------------------
#
# -----------------------------------------------------------------------
# Freevo - A Home Theater PC framework
# Copyright (C) 2003 Krister Lagerstrom, et al. 
# Please see the file freevo/Docs/CREDITS for a complete list of authors.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MER-
# CHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ----------------------------------------------------------------------- */


import os, stat 
import plugin
import config, menu, rc, plugin, util
from gui.AlertBox import AlertBox
from gui.ProgressBox import ProgressBox
from item import Item
from vdr.vdr import VDR
from event import *
import time
import util



class PluginInterface(plugin.DaemonPlugin):
    """
    Some common functions for the vdr plugins.
    """
    
    def __init__(self):
        plugin.DaemonPlugin.__init__(self)
        self.plugin_name='VDRINTERFACE'
        self.variables={}
        self.vdr=VDR(
            host=config.VDR_SVDRP_HOST,
            port=config.VDR_SVDRP_PORT,
            close_connection=config.VDR_SVDRP_ALWAYSCLOSE
            )
        # we didnt fetch the radio epg yet, so set timestamp=0
        self.ts_radio=0
        # set/create cache+settings dir
        self.cachedir='%s/vdrinterface' % config.FREEVO_CACHEDIR
        if not os.path.isdir(self.cachedir):
            os.mkdir(self.cachedir,
                     stat.S_IMODE(os.stat(config.FREEVO_CACHEDIR)[stat.ST_MODE]))
        else:
            # try to load the runtime variables
            self.variables=util.read_pickle(self.cachedir+"/vars")
        if self.variables is None:
            self.variables={}

    def saveVars(self):
        """
        Store runtime variables
        """
        util.save_pickle(self.variables,self.cachedir+"/vars")

    def config(self):
        vars=[
            ['VDR_USE_SVDRP',1,"One can decide to use xine events instead of svdrp commands when using xine as viewer."],
            ['VDR_SVDRP_HOST','localhost','The host that runs vdr'],
            ['VDR_SVDRP_PORT',2001,"VDR's SVDRP port number"],
            ['VDR_SVDRP_ALWAYSCLOSE',0,'Should the SVDRP connection be closed after each command?'],
            ['VDR_VIEWER_PLUGIN','xine',"Which viewer to use for dvb tv. Either 'xine' or 'tvtime'"],
            ['TVTIME_CMD',"/usr/bin/tvtime","Path to tvtime"],
            ['TVTIME_ARGS',"","Optional arguments for tvtime"],
            ]

        return vars

    def getRadioChannels(self):
        """
        Returns a list of channel objects.
        If the channel list is not yet retrieved, do it now.
        """

        now=time.time()

        if not self.vdr.channels:
            self.vdr.retrievechannels()

        channels=self.vdr.radio_channels;

        # do we need to update epg data?
        # for now this is only once in 30 minutes
        if now<self.ts_radio+(60*30):
            # no
            return channels

        popup=ProgressBox(text=_('Collecting channel data.'),full=len(channels))
        popup.show()


        # update epg data
        # get the current programs
        #for chan in channels:
        #   # self.vdr.retrieveepg(chan.id,'now')
        #    popup.tick()

        popup.destroy()

        # store timestamp
        self.ts_radio=time.time()

        return channels

    def getSVDRPConnection(self):
        """
        Returns a fully initialized SVDRP Object.
        """
        return self.vdr.getsvdrp()

    def putVar(self,key,value):
        """
        Put a value into the runtime variable cache.
        """
        self.variables[key]=value

    def getVar(self,key):
        """
        Retrieve a value from the runtime variable cache.
        """
        try:
            value=self.variables[key]
        except:
            return None
        return value
        
        
